CConstaterende datGilze en Rijen
Koppel je AI →
Document · PDF

Geredigeerd Bijlage 19. Omgevingsdialoog samengevoegd bestand Geredigeerd

Gemeenteraad 15 december 2025, gemeente Gilze en RijenBij agendapunt: BOPA Anne Frankplein 12 Rijen (ABG-kantoor)4.119 woorden

Open het PDF bij de gemeente ↗Naar de vergadering →

Tekst van het document

Uit het bestand gehaald, zonder opmaak, tabellen en afbeeldingen

ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

6(oMerS

Vennew, -

Adres

Telefoonnumme

E-mailadres

Noteer hier uw vraag/opmerking

5 er 904000 pokeergcle9 n hUd . In/utric 6P de Vennw:9 nict wenJclJl Mitnc Uit cc

hvdlen Grang

MS purkee(p Ia(K . Groag ook GQAG o0k - Snel ftenrouteyYt BuS / 0V - dro

parkeercckod

iA de

Vennewcg

.C.mICICCA 1V/U)

Oenk QOn

VCrlceErSilegNe ict.

(f Iroute)

(elucd(ve last) wormkponp /Crco /kl Maal bcheLSi hg • p

5.1.2.e

ARC

CLkKjlottii]

।(SÏO^^or^) ,

/et VA teqankely

band md de AVG-wetgeving wordende bovenstaande gegevens alHeen gebruikt vooruit project. Uw gegevens )n-. len n frA ndinn van van dit rn i ect vernietigd, vern iatinr IUw Iw n alleen in gezien door bevoegd personeel van de gemeente en worden naa afronding dit nproject

ll •OAe/

vens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project.

WCekond

(9 ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

Adres UURe qce

359

Telefoonnummer

E-mailadres

Noteer hier uw vraag/opmerking ).

€ K

Lwk WuCC O0A7C

Oeluc

po K

me’

V

eeu

7

eleqechecl

LA

7 ca

r@

ee 1

-uuc Oc>

CXe ekce ie

kecul-

VPeb kecucCe

)u ul

€c

cL

u oL 124 C

Mou /7e

po c(cL

In verband metdeAVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voor dit project. Uw gegevens worden alleen ingezien doorbevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project.

ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

Adres

Só Telefoonnummer

E-mailadres

Noteer hier uw vraag/opmerking

0%rg

7e A24

2/ A

040M Ke

rdongake¥.

Q &zopmne/

escmtcc

goetdl

°n Eeckjó/

rbeden

paveg (70/& 02/ g .

%pepol. &a

M,

%2

VmLag k c.^ o& ke

A,, oé o& 10c& 7 Jc

A .

ID

7

uja+en /P0

by ater Me Aeo

PR parkezh • In verband met de AVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voor dit project Uw gegevens worden alleen in gezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

Adres

C nne

C(

onkplein J

6/220

Telefoonnummer

g.

E-mailadres

Noteer hier uw vraag/opmerking

raoci l

\nolacht.

/00 r

he? /4

rj

Pee/ •

//

®ih.

de Zed verkich < n (2- 1

//

qee^

U

0 S,—6e er / / /

/

In verband metdeAVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voor dit project. Uw gegevens worden alleen in gezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

Adres

(WaN U Qelde I - v ot aeul

*7

Telefoonnummer

E-mailadres

raag/opmerking

VEelevIU

We Poeeu

Uu-veL• cclencle C~ Qclovukew —9 VW OU ‘ UCDV- U VU aen eh qAC Va 3e lck OvVUwL lCO L UDOU 1 v • ca ei al Cil ivl IUW- Bkeevs beikcWoic Ov Ce Ql

ehbeu vU cle UbeWuCel ccu. cl -cA Zeldan vuccuM

In verband metde AVG-wetgevmg wordende bovenstaande gegevens alleen gebruikt voor dit project. Uw gegevens worden alleen in gezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project.

ABG GEMEENTEN

Contactformulier

Zijn al uw vragen beantwoord? Naam

Adres nh€

Y Ru e

P éin BA

5122

en

Telefoonnummer

E-mailadres

Noteer hier uw vraag/opmerking

Kk •ve29 e eg -e ucei11q pqzkeezpZoc Sei) 2 Uh, UOodoog ce pc vecevcvuk opole dVUi qevino We4CyoolI woovo4 7Hde wooudl oldVooeW OWEv 2

In verband metdeAVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voor dit project Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG CEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Adres Naam

e-mail adres

VOw

In verband met deAVG-wetgeving wordende bovenstaande gegevens alleen gebruikt voord it project. Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Naam Adres

e-mail adres

Venngieo 4Z ennevE

é 444 PeI cev9 Ê-e

73

Slolcapkel. 2

In verband met de AVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voord it project. Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Adres Naam

/

edC9 22

8//

V

e-mail adres

L Ce.ul 1

4 7

(Ouuepo.lp( 1 % >1 ld

vVe

>kplelu 8B

12201 (A In verband met de AVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voord it project. Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG CEMEENTEN Aanwezigen '!nformatiebijeenkomst 21 mei 2024: Adres Naam

e-mail adres

PNE-R96 kei Cl KJ 5 1 22 CB

A—, f

<4

€

AM ’

Uevehkg

m

20,wEOc.Am 25

4ne 4Zp/ In verband met deAVG-wetgeving worden de bovenstaande gegevens alleen gebruikt voord it project. Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Naam Adres

'o

" " 6 (9

e-mail adres

In verbandmetdeAVG-wetgevingwordendebovenstaandegegevensalleengebruiktvoorditproject. Uw gegevens worden alleeningeziendoorbevoegdpersoneelvandegemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt in dien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Adres Naam

e-mail adres

Vo edeu 12 Mbel tenewe LO U Q/On 4 rOOt

IS

In verbandmetdeAVG-wetgevingwordendebovenstaandegegevensalleengebruiktvoorditproject. Uw gegevens worden alleen ingezien doorbevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN Aanwezigen informatiebijeenkomst 21 mei 2024: Naam Adres

e-mail adres

4 /4 a. IA NNÉ < } ~W PC A 2(

r

V

V\ovw "hklen wI

COA

2°

]

/ag Zelden2w4oan2Y A/UE

In verband met de AVG-wetgeving wordende bovenstaande gegevens alleen gebruikt voor dit project. Uw gegevens worden alleen ingezien door bevoegd personeel van de gemeente en worden na afronding van dit project vernietigd. Uw gegevens worden alleen gebruikt indien wij of u wenst dat wij contact met u op te nemen omtrent dit project

ABG GEMEENTEN

Verslag gesprek eigenaren/bewoners Venneweg 28 over verdere voorgang van de voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen. Datum: 13 februari 2025 Locatie: Venneweg 28 te Rijen van 16.00 uur tot 17.00 uur

Aanwezig:

m eigenaar/bewoner m eigenaar/bewoner 5.1.2.e

5.1.2.e

projectleider ABG-organisatie

Doel van dit gesprek is om de eigenaren/bewoners van Venneweg 28 te informeren over de

voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen en hen hierbij de gelegenheid te geven om op het conceptplan te reageren en hierover vragen te stellen. De heer Somers laat de schetsen van de huidige planvorming zien en geeft daar een toelichting op. De eigenaren/bewoners konden tijdens dit overleg reageren op de tekeningen en vragen

stellen. De vragen en gegeven antwoorden zijn onderstaande opgenomen.

Vragen en antwoorden Tijdens het gesprek zijn door de eigenaren/bewoners vragen gesteld die de heer Somers heeft beantwoord: Vraag: Hoe zit het met de huidige omzoomde rand met bomen/coniferen. Blijven deze bestaan in de huidige vorm/afmeting? Antwoord: Vooralsnog is er in de plannen rekening gehouden met het handhaven van de

huidige bomenrij. In het verdere verloop van het proces zal daar nader op ingezoomd worden. - Vraag: Hoe wordt het parkeren nu geregeld? Antwoord: Voor het parkeren geldt dat dit via twee ingangen wordt geregeld, te weten: via

de noordzijde vanuit de Mary Zeldenrustlaan alsook aan de zuidzijde via de hoek Anne Frankplein/Stationsplein, maar niet via het snelfietspad.

- Vraag: Hebben we last van geluid van de warmtepompen? Antwoord: Op de hoeken van de noord- en zuidzijde van het dak komen de warmtepompen/zonnepanelen/ luchtbehandelingskasten? De geluidsproductie zal zoveel

mogelijk teruggebracht worden. Zodra merk en type kasten bekand zijn zal nadere informatie

worden gegeven over de geluidsproductie. -Vraag: wordt de parkeerplaats verlicht, in verband voorkomen ongewenst bezoek? Antwoord: Er zal verlichting komen op de parkeerplaats. Hoe en in welke vorm zal nog nader uitgewerkt worden in de plannen van de landschapsarchitect.

Parkeren en verkeersdrukte

1

ABG GEMEENTEN

Er worden enige zorgen geuit over het parkeren aan de Venneweg, deels op het fietspad.

Momenteel valt dat mee, maar heeft onder andere te maken met treinreizigers of niet bewoners van de adressen aan Venneweg. Afgesproken wordt dat wanneer dit op korte termijn, volgens de omwonenden, wederom uit de hand dreigt te lopen, ze dit bij de heer

Somers melden. In dat geval zal dit worden gemeld aan de afdeling handhaving.

De eigenaren/bewoners zijn blij met de functie van een kantoorpand op deze locatie en zien de toekomst met vertrouwen tegemoet.

2

ABG GEMEENTEN

Verslag gesprek eigenaar/bewoner Venneweg 24 over de verdere voorgang van de voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen. Datum: 13 februari 2025 Locatie: Venneweg 24 te Rijen van 17.30 uur tot 18.30 uur

Aanwezig: I eigenaar/bewoner 5.1.2.e

5.1.2.e

projectleider ABG-organisatie

Doel van dit gesprek is om de eigenaar/bewoner van Venneweg 24 te informeren over de

voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen en hen hierbij de gelegenheid te geven om op het conceptplan te reageren en hierover vragen te stellen. De heer Somers laat de schetsen van de huidige planvorming zien en geeft daar een toelichting op. De betreffende eigenaar/bewoner kon tijdens dit gesprek reageren op de tekeningen en

vragen stellen. De vragen en gegeven antwoorden zijn onderstaande opgenomen.

Vragen en antwoorden Tijdens het gesprek zijn door de eigenaar/bewoner vragen gesteld die de heer Somers heeft beantwoord: - Vraag: Hoe wordt het parkeren nu geregeld? Antwoord: Voor het parkeren geldt dat dit via twee ingangen wordt geregeld, te weten: via

de noordzijde vanuit de Mary Zeldenrustlaan alsook aan de zuidzijde via de hoek Anne Frankplein/Stationsplein, maar niet via het snelfietspad.

- Vraag: Hebben we last van geluid van de warmtepompen? Antwoord: Op de hoeken van de noord- en zuidzijde van het dak komen de warmtepompen/zonnepanelen/ luchtbehandelingskasten? De geluidsproductie zal zoveel

mogelijk teruggebracht worden. Zodra merk en type kasten bekand zijn zal nadere informatie

worden gegeven over de geluidsproductie. -Vraag: wordt de parkeerplaats verlicht, in verband voorkomen ongewenst bezoek? Antwoord: Er zal verlichting komen op de parkeerplaats. Hoe en in welke vorm zal nog nader uitgewerkt worden in de plannen van de landschapsarchitect.

Parkeren en verkeersdrukte Er worden enige zorgen geuit over het parkeren aan de Venneweg, deels op het fietspad.

Momenteel valt dat mee, maar dit heeft onder andere te maken met treinreizigers of niet bewoners van de adressen aan Venneweg.

De eigenaar/bewoner geeft aan blij te zijn met de functie van een kantoorpand op deze locatie en ziet de toekomst met vertrouwen tegemoet.

1

ABG CEMEENTEN

De eigenaar/bewoner deelt als laatste mede dat de vorige eigenaren van het perceel Anne Frankplein 12 bereid waren om een bedrag ter beschikking te stellen voor het afschermen van

een deel van de achtertuin van Venneweg 24 ter voorkoming van inkijk.

2

ABG GEMEENTEN

Verslag bijeenkomst omwonenden over voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen. Datum: 19 februari 2025 Locatie: Venneweg 16 te Rijen van 15.00 uur tot 16.00 uur

Aanwezig:

5.1.2.e 5.1.2.e

projectleider ABG-organisatie afd. communicatie ABG-organisatie

Doel van deze bijeenkomst is om de omwonenden te informeren over de voorgenomen

planontwikkeling op locatie Anne Frankplein 12 te Rijen en hen hierbij de gelegenheid te

geven om op het conceptplan te reageren en hierover vragen te stellen.

De heer Somers laat de schetsen van de huidige planvorming zien en geeft daar een

toelichting op. De aanwezigen konden tijdens deze bijeenkomst reageren op de tekeningen en vragen stellen. De vragen en gegeven antwoorden zijn onderstaande opgenomen.

Vragen en antwoorden Tijdens de bijeenkomst zijn door de omwonenden vragen gesteld die 5.1.2.e

heeft

beantwoord: - Vraag: Gaat er met de NS een overleg plaatsvinden over het verleggen van de ingang aan de Vennenweg?

Antwoord: Of dit gaat gebeuren en zo ja wanneer, hangt af van de snelheid van het project

van ProRail. Dat zal later opgepakt worden door ProRail. - Vraag: Zijn de ingangen van het parkeerterrein afsluitbaar? Antwoord: Ja, deze worden afsluitbaar gemaakt. Uitvoering en wijze waarop is nog niet

bekend.

- Vraag: Zijn er voldoende parkeerplaatsen? Antwoord: Ja, op basis van de parkeernorm van de gemeente Gilze en Rijen worden ca. 100

parkeerplaatsen gerealiseerd. De komende perioden wordt hier nog verder onderzoek naar gedaan over de exacte indeling.

-Vraag: Wordt de optie bekeken om het terrein ’s avonds toegankelijk te maken voor omwonenden die willen parkeren? Antwoord: Of daar mogelijkheden toe zijn zal op een later moment gecommuniceerd worden. - Vraag: Komen er zonnepanelen en wordt er gasvrij gebouwd? Antwoord: Voor beide onderdelen is dat positief beantwoord.

1

ABG GEMEENTEN

- Vraag: Op welke hoek van het dak komen de warmtepompen/zonnepanelen/ luchtbehandelingskasten? Antwoord: Deze worden gepositioneerd op de noord-oosthoek en de zuidwestkant van het

dak.

-Vraag: Maken de warmtepompen/zonnepanelen/luchtbehandelingskasten lawaai? Antwoord: De warmtepompen en luchtbehandelingskasten zullen geluid maken, maar er

kan nu nog niet gezegd worden hoeveel dat is. Wel wordt geprobeerd om het geluid tot een minimum te beperken. De dakrand op het gebouw zorgt voor geluidsdemping, evenals de

omkasting rondom deze onderdelen. Het theoretische geluidsniveau wat waarschijnlijk door de installaties geproduceerd wordt kan bij aanschaf van de installaties een keer gedemonstreerd worden.

- Vraag: Wordt er rekening mee gehouden waar het geluid naartoe gaat? Antwoord: Geluid proberen we zoveel mogelijk te reduceren, maar de windrichting bepaalt

welke kant het geluid op gaat. - Vraag; Komen er te openen lichtstraten/-koepels? Antwoord: Daarover kan in deze conceptfase nog niets gezegd worden. Dit soort zaken

kunnen bij een verdere uitwerking van het plan (definitieve ontwerpfase) aan de orde

komen. - Vraag: Worden omliggende straten afgesloten tijdens de bouw? Antwoord: Nee, aannemers krijgen de opdracht om hun bouwplaats inrichting/bouwverkeer

op eigen terrein te realiseren. Dit kan niet altijd, maar mocht dat het geval zijn, dan wordt daarover tijdig gecommuniceerd. - Vraag: Is er lichtoverlast tijdens de avonduren? Antwoord: Nee, maar er wordt wel onderzocht hoe het gebouw verlicht kan worden in het

kader van veiligheid. - Vraag: Wordt met grof geweld gesloopt? Antwoord: We proberen het slopen niet tot overlast te laten zijn,. Daarnaast is het de wens

om zoveel mogelijk materialen te hergebruiken, waardoor de sloop rustiger en meer doordacht uitgevoerd zal moeten worden.

- Vraag: Moet er geheid worden? Antwoord: Nee, er hoeft niet geheid te worden.

- Vraag: Gaat het huidige gebouw helemaal plat? Antwoord: Nee, alleen de “lagere” hoeken/koppen worden gesloopt en de gevels gaan eruit.

- Vraag: Hoelang duurt de bouwfase? Antwoord: De bouwfase start in het vierde kwartaal van 2025 en als alles volgens planning

verloopt wordt het gebouw in het vierde kwartaal van 2026 in gebruik genomen. - Vraag: Komt er een noodtrap aan de buitenkant van het gebouw? Antwoord: Nee, die worden inpandig gerealiseerd.

2

ABG GEMEENTEN

Parkeren en verkeersdrukte

Verder wordt er een suggestie gedaan om de parkeervakken haaks uit te voeren en met

bebording of afzetting trachten te voorkomen dat parkeerplaatsen door NS-reizigers gebruikt gaan worden. Daarnaast zijn er door de omwonenden zorgen geuit over de huidige verkeersdrukte op de

Venneweg (snelfietsroute, bussen en mensen die willen parkeren voor het station) en de parkeerdruk in de straat. Afgesproken wordt dat wanneer dit op korte termijn, volgens de

omwonenden, uit de hand dreigt te lopen, ze dit bij 5.1.2.e

melden. In dat geval zal

dit worden gemeld aan de afdeling handhaving. De aanwezigen geven aan het een mooi plan te vinden en zien de toekomst met vertrouwen

tegemoet.

3

ABG GEMEENTEN

Verslag inloop-/informatieavond voor omwonenden over verdere voortgang van de voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen. Datum: 21 mei 2024 Locatie: Anne Frankplein 12 te Rijen van 18.30 uur tot 20.00 uur

Aanwezig: Diverse omwonenden, zie aanwezigheidslijst 5.1.2.e 5.1.2.e

5.1.2.e

5.1.2.e

architect RoosRos

'Jan, bouwmanagementbureau Hevo

projectleider ABG-organisatie

5.1.2.e

teammanager ABG organisatie

5.1.2.e

directeur ABG organisatie

5.1.2.e

lid stuurgroep ABG-huisvesting

5.1.2.e

Doel van deze bijeenkomst is om de omwonenden te informeren over de start van de

voorgenomen planontwikkeling op de locatie Anne Frankplein 12 te Rijen en hen hierbij de gelegenheid te geven om op de voorgenomen conceptplannen te reageren en hierover vragen te stellen.

De schetsen (plattegronden, gevels , doorsneden, buiteninrichting) van de planconcepten

waren ten toon gespreid en waar nodige hebben de projectleider/architecten/projectmanagers /medewerkers ABG organisatie een toelichting op gegeven. De aanwezigen waren tijdens deze bijeenkomst vrij om te reageren op deze schetsen en beelden en konden uiteraard vragen

stellen. Tijdens de bijeenkomst is verzocht aan de aanwezigen om hun reacties op papier te zetten welke als bijlagen zijn toegevoegd aan dit verslag.

De grootste algemene delers van de opmerkingen hadden betrekking op: wordt er voldoende parkeergelegenheid gerealiseerd; graag geen in-/uitrit aan op de Venneweg; graag parkeerverbod instellen op de Venneweg; geluid(soverlast) van de technische installaties op dak zo minimaal mogelijk houden); graag afgesloten parkeerterrein en niet vrij toegankelijk in de avonden/weekenden; probeer inkijk in de tuinen van de woningen aan de Venneweg te voorkomen; blij met mooie ontwerp, een verbetering ten opzichte van huidige situatie; momenteel parkeeroverlast door bezoekers opleidingen politie/ huisartsenpost/ reizigers met OV; graag aandacht voor verlichting op het parkeerterrein; Toegang parkeerterrein vanaf Mary Zeldenrustlaan en uitgang aan de zuidzijde van het kavel. Dat voorkomt inschijnende autolampen in de woningen en verkeersoverlast op fietspad Mary Zeldenrustlaan.

Opmerkingen over het plan

1

ABG GEMEENTEN

De aanwezigen geven aan het een mooi plan te vinden, zien geen bezwaren tegen de vormgeving en uitstraling van het pand op basis van de getoonde tekeningen en

gevelbeelden. De volgende beelden zijn getoond: Plattegrond van eerste verdieping;

2 stuks Impressies gevelbeelden; Inrichtingsplan kavel met parkeerplaatsen;

Plattegrond bestaande toestand;

Vogelvlucht schets van het plan. Van diverse omwonenden worden vragen gesteld hoe het geregeld gaat worden met alle

verkeersuitdagingen voor alle in ontwikkelingen zijnde nabijgelegen locaties. Er zijn in totaal 250 uitnodigingen verzonden voor de betrokken omwonenden.

2

ABG GEMEENTEN

Verslag inloop informatieavond voor omwonenden over verdere voortgang van de planontwikkeling op de locatie Anne Frankplein 12 te Rijen. Datum: 20 februari 2025 Locatie: “De Boodschap” Nassaulaan 62 te Rijen van 19.00 uur tot 21.00 uur

Aanwezig: Diverse omwonenden, zie aanwezigheidslijst

architect RoosRos

5.1.2.e 5.1.2.e 5.1.2.e

projectleider ABG-organisatie lid stuurgroep ABG-huisvesting

Doel van deze bijeenkomst is om de omwonenden te informeren over de verdere voortgang

van de concept definitieve planontwikkeling op de locatie Anne Frankplein 12 te Rijen en hen hierbij de gelegenheid te geven om op het conceptplan te reageren en hierover vragen te

stellen.

De diverse schetsen (plattegronden, gevels , doorsneden, buiteninrichting) van de planvorming waren ten toon gesteld en waar nodig hebben de projectleider en architect daar

een toelichting op gegeven. De aanwezigen konden tijdens deze bijeenkomst reageren op deze tekeningen en vragen stellen. De vragen en gegeven antwoorden op deze avond zijn onderstaande opgenomen. Er zijn na afloop van de bijeenkomst geen formulieren ingevuld waarop bezoekers hun overige/ aanvullende vragen/opmerkingen hebben ingevuld.

Vragen en antwoorden Tijdens de bijeenkomst zijn door de omwonenden de volgende opmerkingen geplaatst of vragen gesteld, welke als volgt zijn beantwoord: - Vraag: Zijn de ingangen van het parkeerterrein afsluitbaar? Antwoord: Ja, deze worden afsluitbaar gemaakt. Uitvoering en wijze waarop is nog niet

bekend.

- Vraag: Zijn er voldoende parkeerplaatsen? Antwoord: Ja, op basis van de parkeernorm van de gemeente Gilze en Rijen worden ca. 100

parkeerplaatsen gerealiseerd. De komende perioden wordt hier nog verder onderzoek naar gedaan over de exacte indeling.

-Vraag: Wordt de optie bekeken om het terrein ’s avonds toegankelijk te maken voor omwonenden die willen parkeren? Antwoord: Of daar mogelijkheden toe zijn zal op een later moment gecommuniceerd worden.

-Vraag: Maken de warmtepompen/zonnepanelen/luchtbehandelingskasten lawaai?

1

ABG GEMEENTEN

Antwoord: De warmtepompen en luchtbehandelingskasten zullen geluid maken, maar er

kan nu nog niet gezegd worden hoeveel dat is. Wel wordt geprobeerd om het geluid tot een minimum te beperken. De dakrand op het gebouw zorgt voor geluidsdemping, evenals de

omkasting rondom deze onderdelen. Het theoretische geluidsniveau wat waarschijnlijk door de installaties geproduceerd wordt kan bij aanschaf van de installaties een keer gedemonstreerd worden.

- Vraag: Worden omliggende straten opnieuw ingericht? Antwoord: Nee, de omliggende straten blijven behouden behalve de mary Zeldenrustlaan

welke een aantal aanpassingen krijgt. -Vraag: worden er extra parkeerplaatsen aangelegd in het openbaar gebied door de plannen van het toekomstige station, de herontwikkeling van de praxis-locatie en het nieuwe ABG kantoor?

Antwoord: waarschijnlijk niet, de huidige opzet van de parkeerplaatsen op openbaar gebied blijft nagenoeg hetzelfde. De projectleider en architect kunnen hier echter geen concreet

antwoord op geven omdat deze bijeenkomst alleen in het teken staat van de locatie ABG huisvesting. - Vraag: Is er lichtoverlast tijdens de avonduren? Antwoord: Nee, maar er wordt wel onderzocht hoe het gebouw verlicht kan worden in het

kader van veiligheid. - Vraag: Wordt het gehele bestaande pand gesloopt? Antwoord: Nee, een groot gedeelte van het pand blijft intact voor wat betreft de

hoofdconstructie, uitgezonderd de lage vleugels aan de noord- en zuidzijde. We proberen

het slopen van overige onderdelen niet tot overlast te laten zijn. De opzet welke we hebben is om zoveel mogelijk materialen te hergebruiken, waardoor de sloop meer doordacht

uitgevoerd zal moeten worden.

-Vraag: Gaat er voor de uitbouw geheid worden? Antwoord: Nee, er hoeft niet geheid te worden. - Vraag: Wanneer is de start van de bouwfase voorzien en hoe lang duurt deze bouwfase? Antwoord: De bouwfase start in het vierde kwartaal van 2025 en als alles volgens planning

verloopt wordt het gebouw in het vierde kwartaal van 2026 in gebruik genomen. - Vraag: Komt er een noodtrap aan de buitenkant van het gebouw? Antwoord: Nee, die worden inpandig gerealiseerd.

-Vraag: Hoe gaat u voorkomen dat treinreizigers de openbare parkeerplaatsen welke reeds aanwezig zijn gebruiken en hoe wordt dat voor de toekomstige te realiseren parkeerplaatsen aan of in het openbaar gebied geregeld? Antwoord: de huidige openbare parkeerplaatsen vallen niet onder de scope van dit project. Toekomstige parkeerplaatsen behorende tot de toekomstige ABG locatie zullen voor eigen gebruik zijn en niet voor treinreizigers. Dat zal mede worden gerealiseerd door het parkeerterrein afsluitbaar te maken. 2

ABG GEMEENTEN

Parkeren en verkeersdrukte

Een aantal bezoekers geeft expliciet aan dat de toekomstige bouwplannen van ABG-locatie,

herontwikkeling Praxis-locatie en aanpassing station meer verkeer zal betekenen dan momenteel plaats vindt. Er wordt nadrukkelijk op gewezen dat alle plannen in samenhang met elkaar bekeken en afgestemd moeten worden.

Opmerkingen over het plan

De aanwezigen geven aan het een mooi plan te vinden, zien geen bezwaren tegen de vormgeving en uitstraling van het pand op basis van de getoonde tekeningen en

gevelbeelden. De volgende beelden zijn getoond: Plattegrond van de begane grond; Plattegrond van de eerste verdieping; Plattegrond van de tweede verdieping;

Noordoostgevel en oostgevel; Zuidoostgevel en zuidwestgevel; Westgevel en noordgevel;

Doorsnede A-A en doorsnede B-B; Inrichtingsplan kavel met parkeerplaatsen d.d. 06-02-2025 - SB;

3 impressiebeelden van de toekomstige gevels in perspectief; Schaduwanalyse van de nieuwbouw op de directe omgeving van voorjaar, zomer en

herfst. Er zijn in totaal 250 uitnodigingen verzonden voor de betrokken omwonenden.

3

De tekst is automatisch uit het bestand gehaald en kan afwijken van het origineel (kolommen, tabellen en koppen lopen door elkaar). Het officiële stuk bij de gemeente is leidend. Bron: https://api.notubiz.nl/document/16360670/1